@@ -12,7 +12,7 @@ class payUnit:
         self.config_data = data
 
     def makePayment(self,amount): 
-        if(amount <= 0):
+        if(int(amount) <= 0):
             return {"message":"Invalid transaction amount","status":False}
             
         user_api = self.config_data["user_api"]
